
# Class: material sample to entity association mixin


An association between a material sample and something.

URI: [biolink:MaterialSampleToEntityAssociationMixin](https://w3id.org/biolink/vocab/MaterialSampleToEntityAssociationMixin)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[MaterialSample]<subject%201..1-%20[MaterialSampleToEntityAssociationMixin],[MaterialSampleToDiseaseOrPhenotypicFeatureAssociation]uses%20-.->[MaterialSampleToEntityAssociationMixin],[MaterialSampleToDiseaseOrPhenotypicFeatureAssociation],[MaterialSample])](https://yuml.me/diagram/nofunky;dir:TB/class/[MaterialSample]<subject%201..1-%20[MaterialSampleToEntityAssociationMixin],[MaterialSampleToDiseaseOrPhenotypicFeatureAssociation]uses%20-.->[MaterialSampleToEntityAssociationMixin],[MaterialSampleToDiseaseOrPhenotypicFeatureAssociation],[MaterialSample])

## Mixin for

 * [MaterialSampleToDiseaseOrPhenotypicFeatureAssociation](MaterialSampleToDiseaseOrPhenotypicFeatureAssociation.md) (mixin)  - An association between a material sample and a disease or phenotype.

## Referenced by Class


## Attributes


### Own

 * [material sample to entity association mixin➞subject](material_sample_to_entity_association_mixin_subject.md)  <sub>1..1</sub>
     * Description: the material sample being described
     * Range: [MaterialSample](MaterialSample.md)
